==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/RelativeStrengthIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { RelativeStrengthIndexIndicatorDescription } from "./RelativeStrengthIndexIndicatorDescription";
/**
 * @hidden
 */
var RelativeStrengthIndexIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RelativeStrengthIndexIndicatorDescriptionMetadata, _super);
    function RelativeStrengthIndexIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RelativeStrengthIndexIndicatorDescriptionMetadata.b = function (a) {
        if (RelativeStrengthIndexIndicatorDescriptionMetadata.a == null) {
            RelativeStrengthIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RelativeStrengthIndexIndicatorDescriptionMetadata.c(RelativeStrengthIndexIndicatorDescriptionMetadata.a);
        }
        if (a.k(RelativeStrengthIndexIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.ab(RelativeStrengthIndexIndicatorDescriptionMetadata.a);
    };
    RelativeStrengthIndexIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("Period", "Number:int");
    };
    RelativeStrengthIndexIndicatorDescriptionMetadata.d = function (a) {
        RelativeStrengthIndexIndicatorDescriptionMetadata.b(a);
        a.ad("RelativeStrengthIndexIndicator", function () { return new RelativeStrengthIndexIndicatorDescription(); });
        a.ac("RelativeStrengthIndexIndicator", RelativeStrengthIndexIndicatorDescriptionMetadata.a);
    };
    RelativeStrengthIndexIndicatorDescriptionMetadata.$t = markType(RelativeStrengthIndexIndicatorDescriptionMetadata, 'RelativeStrengthIndexIndicatorDescriptionMetadata');
    RelativeStrengthIndexIndicatorDescriptionMetadata.a = null;
    return RelativeStrengthIndexIndicatorDescriptionMetadata;
}(Base));
export { RelativeStrengthIndexIndicatorDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/RelativeStrengthIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { RelativeStrengthIndexIndicatorDescription } from "./RelativeStrengthIndexIndicatorDescription";
/**
 * @hidden
 */
var RelativeStrengthIndexIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RelativeStrengthIndexIndicatorDescriptionMetadata, _super);
    function RelativeStrengthIndexIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RelativeStrengthIndexIndicatorDescriptionMetadata.b = function (a) {
        if (RelativeStrengthIndexIndicatorDescriptionMetadata.a == null) {
            RelativeStrengthIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RelativeStrengthIndexIndicatorDescriptionMetadata.c(RelativeStrengthIndexIndicatorDescriptionMetadata.a);
        }
        if (a.k(RelativeStrengthIndexIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.ac(RelativeStrengthIndexIndicatorDescriptionMetadata.a);
    };
    RelativeStrengthIndexIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("Period", "Number:int");
    };
    RelativeStrengthIndexIndicatorDescriptionMetadata.d = function (a) {
        RelativeStrengthIndexIndicatorDescriptionMetadata.b(a);
        a.ae("RelativeStrengthIndexIndicator", function () { return new RelativeStrengthIndexIndicatorDescription(); });
        a.ad("RelativeStrengthIndexIndicator", RelativeStrengthIndexIndicatorDescriptionMetadata.a);
    };
    RelativeStrengthIndexIndicatorDescriptionMetadata.$t = markType(RelativeStrengthIndexIndicatorDescriptionMetadata, 'RelativeStrengthIndexIndicatorDescriptionMetadata');
    RelativeStrengthIndexIndicatorDescriptionMetadata.a = null;
    return RelativeStrengthIndexIndicatorDescriptionMetadata;
}(Base));
export { RelativeStrengthIndexIndicatorDescriptionMetadata };
